| TDAstats | R Documentation |
This package aims to be a comprehensive toolset for any useR conducting topological data analysis, specifically via the calculation of persistent homology in a Vietoris-Rips complex. The tools this package currently provides can be conveniently split into three main sections: (1) calculating persistent homology; (2) conducting statistical inference on persistent homology calculations; (3) visualizing persistent homology and statistical inference.
Maintainer: Jason Cory Brunson cornelioid@gmail.com
Authors:
Raoul Wadhwa
Andrew Dhawan
Drew Williamson
Jacob Scott
Other contributors:
Shota Ochi [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.